'''
Miscellaneous functions, classes etc
'''

class has_next_iterator(object):
  '''
  A wrapper class for iterators so that the .has_next() method is implemented

  See - http://stackoverflow.com/questions/1966591/hasnext-in-python-iterators
  '''
  def __init__(self, it):
    self.it = iter(it)
    self._has_next = None
  def __iter__(self): return self
  def __next__(self):
    if self._has_next:
      result = self._the_next
    else:
      result = next(self.it)
    self._has_next = None
    return result
  def next(self):
    if self._has_next:
      result = self._the_next
    else:
      result = next(self.it)
    self._has_next = None
    return result
  def has_next(self):
    if self._has_next is None:
      try: 
        self._the_next = next(self.it)
      except StopIteration: self._has_next = False
      else: self._has_next = True
    return self._has_next


def expand_edit_descriptors(eds):
    expanded_eds = []
    for ed in eds:
        if hasattr(ed, 'repeat') and (ed.repeat is not None):
            expanded_eds.extend(ed.repeat * [ed])
        else:
            expanded_eds.append(ed)
    return expanded_eds



import os
from setuptools import setup

HERE = os.path.dirname(os.path.abspath(__file__))
README = ''
with open(HERE + '/README.md') as fh:
    README = fh.read()

setup(
    name='fortranformat',
    packages=['fortranformat'],
    version='1.1.1',
    description='Mimics Fortran textual IO in Python',
    author='Brendan Arnold',
    author_email='brendanarnold@gmail.com',
    url='https://github.com/brendanarnold/py-fortranformat',
    keywords=['fortran', 'io', 'interface', 'format'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Fortran',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Text Processing :: General',
        'Topic :: Software Development :: Interpreters',
        'Topic :: Scientific/Engineering',
    ],
    long_description=README,
    long_description_content_type="text/markdown"
)
